//<c>   Copyright 1986-2000 by Gerry J. Danen; all rights reserved.

//<t>   Interrupt Batch Jobs

//      This program is useful for batch jobs.  If the user wants to interrupt
//      a batch job, but isn't sure what is executing right at the moment, it
//      isn't a good idea to hit Ctrl-C/Break.  Instead, insert the command
//      KEYPRESS in the batch file to check if any key is waiting in the
//      keyboard buffer.  If so, the program pauses, presenting various options
//      to the user.  One of the options is to append the screen image to the
//      disk file "KEYPRESS.IMG" which may later be listed, or otherwise
//      checked for errors, etc.

#include"gd_tools.h"
#include"gd_extrn.h"
#include"gd_kb.h"


UCHAR   *dump ;


void    memory_error( void )
{
    printf( "\nNot enough memory to save screen\n" );
    exit( 100 );
}


int     ask_option( void )
{
    INT16       row, col, fg, bg, ch=-1, offset ;

    CursOff();
    ScBlockRead( dump, 1,1, vid.rows, vid.cols );
    LocateCursor( &row, &col );
    if ( row < 12 )
        offset = 15 ;
    else
        offset = 2 ;
    fg = vid.err_fg ;
    bg = vid.err_bg ;
    box( fg, bg, offset, 5, offset+8, 37, YES, 2 );
    DspMessage( offset+1, 7, fg, bg, "Pause requested by user." );
    DspMessage( offset+3, 7, fg, bg, "C = Continue" );
    DspMessage( offset+4, 7, fg, bg, "D = Dump screen image to file" );
    DspMessage( offset+5, 7, fg, bg, "E = set Errorlevel to 1" );
    DspMessage( offset+7, 7, fg, bg, "Select option: [ ]" );
    CursOn();
    while ( (ch != 'C') && (ch != 'D') && (ch != 'E') )
    {
        FlushKeyboard();                        // prevent type-ahead
        MoveCursor( offset+7,23 );
        sn_beep();                              // beep first
        ch = kb_getkey_();
        DspChar( fg, bg, (UCHAR) ch, 1 );
        ch = toupper( ch );
    }
    CursOff();
    ScBlockWrite( dump, 1,1, vid.rows, vid.cols );
    if ( ch == 'D' )
        Scr2Disk();
    MoveCursor( row, col );
    CursOn();
    FlushKeyboard();
    return( ch );
}


void    main( void )
{
    int ch ;

    if ( ! (ch = kb_getkey_nowait()) )
        exit(0);                        //  no key pressed - exit code = 0
    gd_init( 0 );
    set_global_program_name();
    if ( (dump = malloc( vid.rows * vid.cols * 2 )) == NULL )
        memory_error();
    ScBlockRead( dump, 1,1, vid.rows, vid.cols );
    ch = ask_option();
    if ( ch == 'E' )
        exit(1);                        //  "E" sets exit code = 1
    else
        exit(0);                        //  anything else: exit code = 0
}
